@@ -328,7 +328,7 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
 
 
 
-def fetch_binance_ohlc(symbol = 'BTCUSDT', frequence = '1d', public_key = None, private_key= None, start_time= None, end_time= None, me_month=None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = False, recompute_all=False):
+def fetch_binance_ohlc(symbol = 'BTCUSDT', frequence = '1d', public_key = None, private_key= None, start_time= None, end_time= None, me_month=None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = False, recompute_all=False, save_to_disk = True):
     print('fetching daily tezos')
     if recompute_all:
         binance_df = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time,
@@ -339,7 +339,8 @@ def fetch_binance_ohlc(symbol = 'BTCUSDT', frequence = '1d', public_key = None,
         binance_df['close'] = binance_df['close'].astype(float)
         binance_df['high'] = binance_df['high'].astype(float)
         binance_df['low'] = binance_df['low'].astype(float)
-        save_equity_daily_data(data_df = binance_df, ticker = symbol, frequence=frequence, starting_date=start_time, running_date = end_time, local_root_directory = local_root_directory)
+        if save_to_disk:
+            save_equity_daily_data(data_df = binance_df, ticker = symbol, frequence=frequence, starting_date=start_time, running_date = end_time, local_root_directory = local_root_directory)
     else :
         try :
             filename = symbol + '_' + frequence + '_' + start_time.strftime('%d_%b_%Y') + '_' + end_time.strftime(
@@ -355,7 +356,8 @@ def fetch_binance_ohlc(symbol = 'BTCUSDT', frequence = '1d', public_key = None,
             binance_df['close'] = binance_df['close'].astype(float)
             binance_df['high'] = binance_df['high'].astype(float)
             binance_df['low'] = binance_df['low'].astype(float)
-            save_equity_daily_data(data_df=binance_df, ticker=symbol, frequence=frequence, starting_date=start_time,
+            if save_to_disk:
+                save_equity_daily_data(data_df=binance_df, ticker=symbol, frequence=frequence, starting_date=start_time,
                                    running_date=end_time, local_root_directory=local_root_directory)
 
     return binance_df
