@@ -138,9 +138,9 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
 
         print('Loading data')
         if exchange is None:
-            day_url_request = 'https://min-api.cryptocompare.com/data/v2/histoday?fsym={}&tsym='+ssj_against+'&toTs={}&limit=2000'
+            day_url_request = 'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym='+ssj_against+'&toTs={}&limit=2000'
         else :
-            day_url_request = 'https://min-api.cryptocompare.com/data/v2/histoday?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
+            day_url_request = 'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
 
         dataframe = None
         for me_timestamp in [ts8,ts7,ts6,ts5,ts4,ts3,ts2,ts1,ts]:
